import clsx from 'clsx';
import React, { useMemo } from 'react';

function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var styles = {"fcc__container":"_qWTcH","fcc__label_show":"_1tbqx","fcc__digit_block_container":"_3cpN7","fcc__digit_block":"_2EBbg","fcc__digit_block_label":"_2aOn7","fcc__current_below":"_106d2","fcc__next_above":"_SKh-V","fcc__card":"_3luxx","fcc__flipped":"_2kgZC","fcc__card_face":"_2v-d4","fcc__card_face_front":"_1GZQ7","fcc__card_face_back":"_3AVXa","fcc__colon":"_2hRXr"};

function FlipClockDigit(props) {
  var _clsx;

  var current = props.current,
      next = props.next,
      className = props.className,
      style = props.style;

  var _React$useState = React.useState({
    current: current,
    next: next
  }),
      digit = _React$useState[0],
      setDigit = _React$useState[1];

  var _React$useState2 = React.useState(false),
      flipped = _React$useState2[0],
      setFlipped = _React$useState2[1];

  React.useEffect(function () {
    if (digit.current !== current) {
      if (digit.current === digit.next) {
        setDigit(_extends({}, digit, {
          next: next
        }));
      }

      setFlipped(true);
    } else {
      setFlipped(false);
    }
  }, [current, next]);

  var handleTransitionEnd = function handleTransitionEnd() {
    setDigit({
      current: current,
      next: next
    });
    setFlipped(false);
  };

  return React.createElement("div", {
    className: clsx(styles.fcc__digit_block, className),
    style: style
  }, React.createElement("div", {
    className: styles.fcc__next_above
  }, digit.next), React.createElement("div", {
    className: styles.fcc__current_below
  }, digit.current), React.createElement("div", {
    className: clsx(styles.fcc__card, (_clsx = {}, _clsx[styles.fcc__flipped] = flipped, _clsx)),
    onTransitionEnd: handleTransitionEnd
  }, React.createElement("div", {
    className: clsx(styles.fcc__card_face, styles.fcc__card_face_front)
  }, digit.current), React.createElement("div", {
    className: clsx(styles.fcc__card_face, styles.fcc__card_face_back)
  }, digit.next)));
}

function calcTimeDelta(target) {
  var date = new Date(target);

  if (isNaN(date.getTime())) {
    throw Error('Invalid date');
  }

  var now = new Date();
  var timeLeft = Math.round((date.getTime() - now.getTime()) / 1000);
  if (timeLeft < 0) timeLeft = 0;
  return {
    total: timeLeft,
    days: Math.floor(timeLeft / (24 * 60 * 60)),
    hours: Math.floor(timeLeft / 3600 % 24),
    minutes: Math.floor(timeLeft / 60 % 60),
    seconds: Math.floor(timeLeft % 60)
  };
}
function pad(n) {
  return ('0'.repeat(Math.max(0, 2 - String(n).length)) + String(n)).split('');
}
function parseTimeDelta(timeDelta) {
  var nextTimeDelta = calcTimeDelta(new Date().getTime() + (timeDelta.total - 1) * 1000);
  return {
    days: {
      current: pad(timeDelta.days),
      next: pad(nextTimeDelta.days)
    },
    hours: {
      current: pad(timeDelta.hours),
      next: pad(nextTimeDelta.hours)
    },
    minutes: {
      current: pad(timeDelta.minutes),
      next: pad(nextTimeDelta.minutes)
    },
    seconds: {
      current: pad(timeDelta.seconds),
      next: pad(nextTimeDelta.seconds)
    }
  };
}
function convertToPx(n) {
  if (n === undefined) return undefined;
  if (typeof n === 'string') return n;
  return n + "px";
}

var _excluded = ["to", "className", "style", "children", "onComplete", "onTick", "showLabels", "showSeparators", "labels", "labelStyle", "digitBlockStyle", "separatorStyle", "dividerStyle", "duration"];

function FlipClockCountdown(props) {
  var _clsx;

  var to = props.to,
      className = props.className,
      style = props.style,
      children = props.children,
      onComplete = props.onComplete,
      onTick = props.onTick,
      showLabels = props.showLabels,
      showSeparators = props.showSeparators,
      labels = props.labels,
      labelStyle = props.labelStyle,
      digitBlockStyle = props.digitBlockStyle,
      separatorStyle = props.separatorStyle,
      dividerStyle = props.dividerStyle,
      duration = props.duration,
      other = _objectWithoutPropertiesLoose(props, _excluded);

  var _React$useState = React.useState(),
      state = _React$useState[0],
      setState = _React$useState[1];

  var countdownRef = React.useRef(0);

  function clearTimer() {
    window.clearInterval(countdownRef.current);
  }

  function constructState() {
    var timeDelta = calcTimeDelta(to);
    return {
      timeDelta: timeDelta,
      completed: timeDelta.total === 0
    };
  }

  function tick() {
    var newState = constructState();
    setState(newState);
    onTick(newState);

    if (newState.completed) {
      clearTimer();
      onComplete();
    }
  }

  React.useEffect(function () {
    setState(constructState());
    clearTimer();
    countdownRef.current = window.setInterval(tick, 1000);
    return function () {
      return clearTimer();
    };
  }, [to]);
  var containerStyles = React.useMemo(function () {
    var s = _extends({
      '--fcc-flip-duration': duration === undefined || duration < 0 || duration > 1 ? undefined : duration + "s",
      '--fcc-digit-block-width': convertToPx(digitBlockStyle === null || digitBlockStyle === void 0 ? void 0 : digitBlockStyle.width),
      '--fcc-digit-block-height': convertToPx(digitBlockStyle === null || digitBlockStyle === void 0 ? void 0 : digitBlockStyle.height),
      '--fcc-shadow': digitBlockStyle === null || digitBlockStyle === void 0 ? void 0 : digitBlockStyle.boxShadow,
      '--fcc-digit-font-size': convertToPx(digitBlockStyle === null || digitBlockStyle === void 0 ? void 0 : digitBlockStyle.fontSize),
      '--fcc-digit-color': digitBlockStyle === null || digitBlockStyle === void 0 ? void 0 : digitBlockStyle.color,
      '--fcc-label-font-size': convertToPx(labelStyle === null || labelStyle === void 0 ? void 0 : labelStyle.fontSize),
      '--fcc-label-color': labelStyle === null || labelStyle === void 0 ? void 0 : labelStyle.color,
      '--fcc-divider-color': dividerStyle === null || dividerStyle === void 0 ? void 0 : dividerStyle.color,
      '--fcc-divider-height': convertToPx(dividerStyle === null || dividerStyle === void 0 ? void 0 : dividerStyle.height),
      '--fcc-background': (digitBlockStyle === null || digitBlockStyle === void 0 ? void 0 : digitBlockStyle.background) || (digitBlockStyle === null || digitBlockStyle === void 0 ? void 0 : digitBlockStyle.backgroundColor),
      '--fcc-separator-size': convertToPx(separatorStyle === null || separatorStyle === void 0 ? void 0 : separatorStyle.size),
      '--fcc-separator-color': showSeparators ? separatorStyle === null || separatorStyle === void 0 ? void 0 : separatorStyle.color : 'transparent'
    }, style);

    return s;
  }, [style, digitBlockStyle, labelStyle, duration, dividerStyle, separatorStyle, showSeparators]);

  var _digitBlockStyle = useMemo(function () {
    if (digitBlockStyle) {
      return _extends({}, digitBlockStyle, {
        background: undefined,
        backgroundColor: undefined,
        width: undefined,
        height: undefined,
        boxShadow: undefined,
        fontSize: undefined,
        color: undefined
      });
    }

    return undefined;
  }, [digitBlockStyle]);

  var renderProps = React.useMemo(function () {
    if (state === undefined) return undefined;
    var timeDelta = state.timeDelta;
    return _extends({}, timeDelta, {
      formatted: parseTimeDelta(timeDelta)
    });
  }, [state]);
  if (state === undefined || renderProps === undefined) return React.createElement(React.Fragment, null);

  if (state !== null && state !== void 0 && state.completed) {
    return React.createElement(React.Fragment, null, children);
  }

  var _renderProps$formatte = renderProps.formatted,
      days = _renderProps$formatte.days,
      hours = _renderProps$formatte.hours,
      minutes = _renderProps$formatte.minutes,
      seconds = _renderProps$formatte.seconds;

  var _labels = labels.length >= 4 ? labels : ['Days', 'Hours', 'Minutes', 'Seconds'];

  return React.createElement("div", Object.assign({}, other, {
    className: clsx(styles.fcc__container, (_clsx = {}, _clsx[styles.fcc__label_show] = showLabels, _clsx), className),
    style: containerStyles,
    "data-testid": 'fcc-container'
  }), [days, hours, minutes, seconds].map(function (item, idx) {
    return React.createElement(React.Fragment, {
      key: "digit-block-" + idx
    }, React.createElement("div", {
      className: styles.fcc__digit_block_container
    }, showLabels && React.createElement("div", {
      className: styles.fcc__digit_block_label,
      style: labelStyle
    }, _labels[idx]), item.current.map(function (cItem, cIdx) {
      return React.createElement(FlipClockDigit, {
        key: cIdx,
        current: cItem,
        next: item.next[cIdx],
        style: _digitBlockStyle
      });
    })), idx < 3 && React.createElement("div", {
      className: styles.fcc__colon
    }));
  }));
}

FlipClockCountdown.defaultProps = {
  onComplete: function onComplete() {},
  onTick: function onTick() {},
  labels: ['Days', 'Hours', 'Minutes', 'Seconds'],
  showLabels: true,
  showSeparators: true
};

export default FlipClockCountdown;
//# sourceMappingURL=index.modern.js.map
